/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtdeclarative_python.h"

#include "qdeclarativeimageprovider_wrapper.h"

// Extra includes
#include <qimage.h>
#include <qpixmap.h>
#include <qsize.h>


// Native ---------------------------------------------------------

QDeclarativeImageProviderWrapper::QDeclarativeImageProviderWrapper(QDeclarativeImageProvider::ImageType type) : QDeclarativeImageProvider(type) {
    // ... middle
}

QImage QDeclarativeImageProviderWrapper::requestImage(const QString & id, QSize * size, const QSize & requestedSize)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QImage();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "requestImage"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDeclarativeImageProvider::requestImage(id, size, requestedSize);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< QString >::toPython(id),
        Shiboken::Converter< ::QSize * >::toPython(size),
        Shiboken::Converter< ::QSize >::toPython(requestedSize)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QImage();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QImage >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeImageProvider.requestImage", Shiboken::SbkType<QImage >()->tp_name, pyResult->ob_type->tp_name);
        return QImage();
    }
    QImage cppResult(Shiboken::Converter< ::QImage >::toCpp(pyResult));
    return cppResult;
}

QPixmap QDeclarativeImageProviderWrapper::requestPixmap(const QString & id, QSize * size, const QSize & requestedSize)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QPixmap();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "requestPixmap"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDeclarativeImageProvider::requestPixmap(id, size, requestedSize);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< QString >::toPython(id),
        Shiboken::Converter< ::QSize * >::toPython(size),
        Shiboken::Converter< ::QSize >::toPython(requestedSize)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QPixmap();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPixmap >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeImageProvider.requestPixmap", Shiboken::SbkType<QPixmap >()->tp_name, pyResult->ob_type->tp_name);
        return QPixmap();
    }
    QPixmap cppResult(Shiboken::Converter< ::QPixmap >::toCpp(pyResult));
    return cppResult;
}

QDeclarativeImageProviderWrapper::~QDeclarativeImageProviderWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDeclarativeImageProvider_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QDeclarativeImageProvider >()))
        return -1;

    QDeclarativeImageProviderWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QDeclarativeImageProvider", 1, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QDeclarativeImageProvider(QDeclarativeImageProvider::ImageType)
    if (numArgs == 1 && Shiboken::Converter< ::QDeclarativeImageProvider::ImageType >::isConvertible(pyargs[0])) {
        overloadId = 0; // QDeclarativeImageProvider(QDeclarativeImageProvider::ImageType)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeImageProvider_Init_TypeError;

    // Call function/method
    {
        {
            QDeclarativeImageProvider::ImageType cppArg0 = Shiboken::Converter<QDeclarativeImageProvider::ImageType >::toCpp(pyargs[0]);

            if(!PyErr_Occurred()) {
                // QDeclarativeImageProvider(QDeclarativeImageProvider::ImageType)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QDeclarativeImageProviderWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QDeclarativeImageProvider >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QDeclarativeImageProvider_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QDeclarativeImageProvider_Init_TypeError:
        const char* overloads[] = {"PySide.QtDeclarative.QDeclarativeImageProvider.ImageType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeImageProvider", overloads);
        return -1;
}

static PyObject* Sbk_QDeclarativeImageProviderFunc_imageType(PyObject* self)
{
    QDeclarativeImageProvider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeImageProvider* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // imageType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDeclarativeImageProvider::ImageType cppResult = const_cast<const QDeclarativeImageProvider*>(cppSelf)->imageType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDeclarativeImageProvider::ImageType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeImageProviderFunc_requestImage(PyObject* self, PyObject* args)
{
    QDeclarativeImageProvider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeImageProvider* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "requestImage", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: requestImage(QString,QSize*,QSize)
    if (numArgs == 3 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QSize * >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QSize >::isConvertible(pyargs[2])) {
        overloadId = 0; // requestImage(QString,QSize*,QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeImageProviderFunc_requestImage_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QSize * cppArg1 = Shiboken::Converter<QSize * >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QSize cppArg2 = Shiboken::Converter<QSize >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // requestImage(QString,QSize*,QSize)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QImage cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QDeclarativeImageProvider::requestImage(cppArg0, cppArg1, cppArg2) : cppSelf->requestImage(cppArg0, cppArg1, cppArg2));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QImage >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDeclarativeImageProviderFunc_requestImage_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QSize, PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeImageProvider.requestImage", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativeImageProviderFunc_requestPixmap(PyObject* self, PyObject* args)
{
    QDeclarativeImageProvider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeImageProvider* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "requestPixmap", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: requestPixmap(QString,QSize*,QSize)
    if (numArgs == 3 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QSize * >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QSize >::isConvertible(pyargs[2])) {
        overloadId = 0; // requestPixmap(QString,QSize*,QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeImageProviderFunc_requestPixmap_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QSize * cppArg1 = Shiboken::Converter<QSize * >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QSize cppArg2 = Shiboken::Converter<QSize >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // requestPixmap(QString,QSize*,QSize)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPixmap cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QDeclarativeImageProvider::requestPixmap(cppArg0, cppArg1, cppArg2) : cppSelf->requestPixmap(cppArg0, cppArg1, cppArg2));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPixmap >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDeclarativeImageProviderFunc_requestPixmap_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QSize, PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeImageProvider.requestPixmap", overloads);
        return 0;
}

static PyMethodDef Sbk_QDeclarativeImageProvider_methods[] = {
    {"imageType", (PyCFunction)Sbk_QDeclarativeImageProviderFunc_imageType, METH_NOARGS},
    {"requestImage", (PyCFunction)Sbk_QDeclarativeImageProviderFunc_requestImage, METH_VARARGS},
    {"requestPixmap", (PyCFunction)Sbk_QDeclarativeImageProviderFunc_requestPixmap, METH_VARARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QDeclarativeImageProvider_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtDeclarative.QDeclarativeImageProvider",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QDeclarativeImageProvider_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QDeclarativeImageProvider_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QDeclarativeImageProvider(PyObject* module)
{
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEIMAGEPROVIDER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QDeclarativeImageProvider_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QDeclarativeImageProvider_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QDeclarativeImageProvider_Type, &Shiboken::callCppDestructor<QDeclarativeImageProvider >);
    Py_INCREF((PyObject*)&Sbk_QDeclarativeImageProvider_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QDeclarativeImageProvider_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_QDeclarativeImageProvider_Type, "QDeclarativeImageProvider*");
    PyModule_AddObject(module, "QDeclarativeImageProvider",
        ((PyObject*)&Sbk_QDeclarativeImageProvider_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: ImageType
    PyTypeObject* SbkPySide_QtDeclarative_QDeclarativeImageProvider_ImageType = Shiboken::Enum::newType("PySide.QtDeclarative.QDeclarativeImageProvider.ImageType");
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEIMAGEPROVIDER_IMAGETYPE_IDX] = SbkPySide_QtDeclarative_QDeclarativeImageProvider_ImageType;
    if (PyType_Ready(SbkPySide_QtDeclarative_QDeclarativeImageProvider_ImageType) < 0)
        return;
    PyDict_SetItemString(Sbk_QDeclarativeImageProvider_Type.super.ht_type.tp_dict,
            "ImageType",((PyObject*)SbkPySide_QtDeclarative_QDeclarativeImageProvider_ImageType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtDeclarative_QDeclarativeImageProvider_ImageType,(long) QDeclarativeImageProvider::Image, "Image");
    PyDict_SetItemString(Sbk_QDeclarativeImageProvider_Type.super.ht_type.tp_dict,"Image", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeImageProvider_ImageType->tp_dict,"Image", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtDeclarative_QDeclarativeImageProvider_ImageType,(long) QDeclarativeImageProvider::Pixmap, "Pixmap");
    PyDict_SetItemString(Sbk_QDeclarativeImageProvider_Type.super.ht_type.tp_dict,"Pixmap", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeImageProvider_ImageType->tp_dict,"Pixmap", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDeclarativeImageProvider::ImageType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ImageType");
    // end of enum ImageType


    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeImageProvider >("QDeclarativeImageProvider*");
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeImageProvider >(typeid(QDeclarativeImageProvider).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeImageProvider >(typeid(QDeclarativeImageProviderWrapper).name());
    qRegisterMetaType< ::QDeclarativeImageProvider* >("QDeclarativeImageProvider*");
    qRegisterMetaType< ::QDeclarativeImageProvider::ImageType >("QDeclarativeImageProvider::ImageType");
}

